==> stalker42-0.3.0.tar.gz: stalker42-0.3.0/stalker42/stalker.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
##########################################
# AUTHOR:   p-tank <akazian@student.42.fr>
# FILE:     stalker42.py
# CREATED:  17:19:04 04/06/2014
# MODIFIED: 17:19:04 07/06/2014
##########################################

import os
import re
import requests
import csv
from ldap3 import Server, Connection, AUTH_SIMPLE, STRATEGY_SYNC, SEARCH_SCOPE_WHOLE_SUBTREE
from bs4 import BeautifulSoup

class Stalker42: # complete tool to stalk 42 student

        verbose = False

        def __init__(self, contactfile=False):
                self.intraSession = requests.Session()
                self.dashboardSession = requests.Session()
                self.urlCrawler = 'https://dashboard.42.fr/crawler/pull/'
                self.urlDashboard = 'https://dashboard.42.fr/login/'
                self.urlIntra = 'https://intra.42.fr'
                self.urlLdap = 'ldaps://ldap.42.fr'
                if contactfile:
                        self.contactcsv = contactfile
                else:
                        self.contactcsv = 'contact.csv'
                try:
                        with open(self.contactcsv, "r+") as csvfile:
                                c = csv.reader(csvfile, delimiter=';', quotechar='|')
                                self.contact = {rows[0]:rows[1] for rows in c}
                                del self.contact["Name"]
                                csvfile.close()
                except:
                        self.contact = {}
                        if Stalker42.verbose:
                                print("You can add friends with stalker42.addContact(arg, 'friend')")
                if Stalker42.verbose:
                        print("Stalker42: constructed")

        def __str__(self):
                return ("Stalker42: version: 1.0")

        def __getattr__(self, attr):
                if Stalker42.verbose:
                        print("Stalker42: No attribut named '" + attr + "' here.")

        def findPlace(self, name): # function to check place in crawler
                req = requests.get(self.urlCrawler + name, verify=False)
                host = req.text
                match = re.search('((last_host": ")(.+)(.42.fr"))', host)
                if match:
                        if Stalker42.verbose:
                                print("Stalker42: place found")
                        return(match.group(3))
                else:
                        if Stalker42.verbose:
                                print("Stalker42: place not found")
                        return("Not found")

        def getInfo(self, contacts): # return a tuple
                ret = []
                for name in contacts:
                        ret.append({'name': name['name'],
                                    'place': self.findPlace(name['name']),
                                    'project': name['project'],
                                    'status': name['status'],
                                    'mail': self.getMail(name['name']),
                                    'tel': self.getTel(name['name'])})
                return (ret)

        def getContact(self, status = False): # return contact for status in a dict
                ret = {}
                if status:
                        for name in self.contact:
                                if self.contact[name] == status:
                                        ret[name] = status
                        if Stalker42.verbose:
                                print("Stalker.42: contact done for status: " + status)
                        return (ret)
                else:
                        if Stalker42.verbose:
                                print("Stalker42: all contact done")
                        return (self.contact)

        def saveContact(self): # save contact dic in csv file
                 with open(self.contactcsv, "w") as csvfile:
                        c = csv.writer(csvfile, delimiter=';', quotechar='|')
                        c.writerow(["Name", "Status"])
                        for name in self.contact:
                                c.writerow([name, self.contact[name]])
                        csvfile.close()
                 if Stalker42.verbose:
                        print("Stalker42: contact saved in contact.csv")

        def addContact(self, contact, status): # add contact
                if status == "Status":
                    if Stalker42.verbose:
                        print("Stalker42: status can't be named 'Status'")
                    return
                if type(contact) is str:
                        self.contact[contact] = status
                else:
                        for name in contact:
                                self.contact[name] = status
                self.saveContact()
                if Stalker42.verbose:
                        print("Stalker42: contact added" + status + " as status")

        def delContact(self, name):
                try:
                        if type(name) is str:
                                del self.contact[name]
                        else:
                                for n in name:
                                        del self.contact[n]
                        self.saveContact()
                        if Stalker42.verbose:
                                print("Stalker42: contact deleted")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't delete " + name)

        def findContact(self, status=False, contact=None): # find people from dictionary
                ret = []
                if contact:
                        for name in contact:
                                ret.append({'name' : name,
                                           'project': None,
                                           'status': status})
                else:
                        for name in self.contact:
                                 try:
                                            if status == False or self.contact[name] == status:
                                                        ret.append({'name' : name,
                                                                    'project': "Not found",
                                                                    'status': self.contact[name]})
                                 except:
                                            if Stalker42.verbose:
                                                        print("Stalker42: error status for: "+ status)
                                            return
                if Stalker42.verbose:
                        if status is False:
                                status = "all"
                        print("Stalker42: dictionary " + status + " ended")
                return (self.getInfo(ret))

        def connectIntra(self, user=False, pwd=False):
                data = {}
                if user and pwd:
                        data = {"login": user, "password": pwd}
                try:
                        intra = self.intraSession.post(self.urlIntra, data=data, verify=False)
                        intra.encoding = 'utf-8'
                        self.intra = intra.text
                        if Stalker42.verbose:
                                print("Stalker42: " + self.urlIntra + " connected")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect " + self.urlIntra)
                        return (False)
                if re.findall('Anonymous',self.intra):
                        return (False)
                return (True)

        def connectDashboard(self, user=False, pwd=False):
                data = {}
                headers = {"User-Agent" : "Mozilla/5.0 (X11; Linux x86_64; rv:12.0) Gecko/20100101 Firefox/21.0"}
                if user and pwd:
                        data = {"login": user, "password": pwd}
                try:
                        self.dashboard = self.dashboardSession.post(self.urlDashboard, data=data, headers=headers, verify=False)
                        if Stalker42.verbose:
                                print("Stalker42: " + self.urlDashboard + " connected")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect " + self.urlDashboard)
                        return (False)
                if re.findall('login',self.dashboard.text):
                        return (False)
                return(True)

        def findCorrector(self):
                ret = []
                if self.intra == None:
                        if Stalker42.verbose:
                                print("Stalker42: You must be connected to the intra")
                        return ()
                soup = BeautifulSoup(self.intra)
                peer = soup.find_all("div", {"class": "column peering"})
                for block in peer:
                        block = block.get_text()
                        try:
                                project = re.search("sur le projet (.+) avant", block).group(1)
                        except:
                                project = "Not found"
                        match = re.findall('(\(e\) par )(.+)', block)
                        if match:
                                for corrector in match:
                                             ret.append({'name': corrector[1],
                                                         'project': project,
                                                         'status': 'corrector'})
                return(self.getInfo(ret))

        def connectLdap(self, login, pwd): # connec to ldap and put tel mail uid in self.ldap
                try:
                        user = ('uid='+ login + ', ou=2013, ou=people, dc=42, dc=fr')
                        server = Server(self.urlLdap, port = 636, use_ssl = True)
                        connection = Connection(server, auto_bind = True, client_strategy = STRATEGY_SYNC, user=user, password=pwd, authentication=AUTH_SIMPLE)

                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect to ldap")
                        return (False)
                try:
                        connection.search('ou=people, dc=42, dc=fr','(objectClass=*)', SEARCH_SCOPE_WHOLE_SUBTREE, attributes = ['uid', 'alias', 'mobile-phone'])
                        self.ldap = connection.response
                        connection.unbind()
                except:
                        if Stalker42.verbose:
                                print("Stalker42: ldap search error")
                        connection.unbind()
                        return (False)
                if Stalker42.verbose:
                        print("Stalker42: " + self.urlLdap + " connected")
                return (True)

        def connectLdapSchool(self): # connec to ldap and put tel mail uid in self.ldap at school
                try:
                        user = ('ou=2013, ou=people, dc=42, dc=fr')
                        server = Server(self.urlLdap, port = 389)
                        connection = Connection(server, auto_bind = True, client_strategy = STRATEGY_SYNC, user=user)

                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect to ldap")
                        return (False)
                try:
                        connection.search('ou=people, dc=42, dc=fr','(objectClass=*)', SEARCH_SCOPE_WHOLE_SUBTREE, attributes = ['uid', 'alias', 'mobile-phone'])
                        self.ldap = connection.response
                        connection.unbind()
                except:
                        if Stalker42.verbose:
                                print("Stalker42: ldap search error")
                        connection.unbind()
                        return (False)
                if Stalker42.verbose:
                        print("Stalker42: " + self.urlLdap + " connected")
                return (True)

        def getMail(self, name):
                if self.ldap:
                        for user in self.ldap:
                                attr = user['attributes']
                                try:
                                        if attr['uid'][0] == name:
                                               return (attr['alias'][0])
                                except:
                                        if Stalker42.verbose:
                                               print("Stalker42: can't find ldap element")
                return ('Not found')

        def getTel(self, name):
                if self.ldap:
                        for user in self.ldap:
                                attr = user['attributes']
                                try:
                                        if attr['uid'][0] == name:
                                               return (attr['mobile-phone'][0])
                                except:
                                        if Stalker42.verbose:
                                               print("Stalker42: can't find ldap element")
                return ('Not found')                      

        def __del__(self):
                if Stalker42.verbose:
                        print("Stalker42: object deleted")

==> stalker42-0.3.1.tar.gz: stalker42-0.3.1/stalker42/stalker.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
##########################################
# AUTHOR:   p-tank <akazian@student.42.fr>
# FILE:     stalker42.py
# CREATED:  17:19:04 04/06/2014
# MODIFIED: 17:19:04 07/06/2014
##########################################

import os
import re
import requests
import csv
from ldap3 import Server, Connection, AUTH_SIMPLE, STRATEGY_SYNC, SEARCH_SCOPE_WHOLE_SUBTREE
from bs4 import BeautifulSoup

class Stalker42: # complete tool to stalk 42 student

        verbose = False

        def __init__(self, contactfile=False):
                self.intraSession = requests.Session()
                self.dashboardSession = requests.Session()
                self.urlCrawler = 'https://dashboard.42.fr/crawler/pull/'
                self.urlDashboard = 'https://dashboard.42.fr/login/'
                self.urlIntra = 'https://intra.42.fr'
                self.urlLdap = 'ldaps://ldap.42.fr'
                if contactfile:
                        self.contactcsv = contactfile
                else:
                        self.contactcsv = 'contact.csv'
                try:
                        with open(self.contactcsv, "r+") as csvfile:
                                c = csv.reader(csvfile, delimiter=';', quotechar='|')
                                self.contact = {rows[0]:rows[1] for rows in c}
                                del self.contact["Name"]
                                csvfile.close()
                except:
                        self.contact = {}
                        if Stalker42.verbose:
                                print("You can add friends with stalker42.addContact(arg, 'friend')")
                if Stalker42.verbose:
                        print("Stalker42: constructed")

        def __str__(self):
                return ("Stalker42: version: 1.0")

        def __getattr__(self, attr):
                if Stalker42.verbose:
                        print("Stalker42: No attribut named '" + attr + "' here.")

        def findPlace(self, name): # function to check place in crawler
                req = requests.get(self.urlCrawler + name, verify=False)
                host = req.text
                match = re.search('((last_host": ")(.+)(.42.fr"))', host)
                if match:
                        if Stalker42.verbose:
                                print("Stalker42: place found")
                        return(match.group(3))
                else:
                        if Stalker42.verbose:
                                print("Stalker42: place not found")
                        return("Not found")

        def getInfo(self, contacts): # return a tuple
                ret = []
                for name in contacts:
                        ret.append({'name': name['name'],
                                    'place': self.findPlace(name['name']),
                                    'project': name['project'],
                                    'status': name['status'],
                                    'mail': self.getMail(name['name']),
                                    'tel': self.getTel(name['name'])})
                return (ret)

        def getContact(self, status = False): # return contact for status in a dict
                ret = {}
                if status:
                        for name in self.contact:
                                if self.contact[name] == status:
                                        ret[name] = status
                        if Stalker42.verbose:
                                print("Stalker.42: contact done for status: " + status)
                        return (ret)
                else:
                        if Stalker42.verbose:
                                print("Stalker42: all contact done")
                        return (self.contact)

        def saveContact(self): # save contact dic in csv file
                 with open(self.contactcsv, "w") as csvfile:
                        c = csv.writer(csvfile, delimiter=';', quotechar='|')
                        c.writerow(["Name", "Status"])
                        for name in self.contact:
                                c.writerow([name, self.contact[name]])
                        csvfile.close()
                 if Stalker42.verbose:
                        print("Stalker42: contact saved in contact.csv")

        def addContact(self, contact, status): # add contact
                if status == "Status":
                    if Stalker42.verbose:
                        print("Stalker42: status can't be named 'Status'")
                    return
                if type(contact) is str:
                        self.contact[contact] = status
                else:
                        for name in contact:
                                self.contact[name] = status
                self.saveContact()
                if Stalker42.verbose:
                        print("Stalker42: contact added" + status + " as status")

        def delContact(self, name):
                try:
                        if type(name) is str:
                                del self.contact[name]
                        else:
                                for n in name:
                                        del self.contact[n]
                        self.saveContact()
                        if Stalker42.verbose:
                                print("Stalker42: contact deleted")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't delete " + name)

        def findContact(self, status=False, contact=None): # find people from dictionary
                ret = []
                if contact:
                        for name in contact:
                                ret.append({'name' : name,
                                           'project': None,
                                           'status': status})
                else:
                        for name in self.contact:
                                 try:
                                            if status == False or self.contact[name] == status:
                                                        ret.append({'name' : name,
                                                                    'project': "Not found",
                                                                    'status': self.contact[name]})
                                 except:
                                            if Stalker42.verbose:
                                                        print("Stalker42: error status for: "+ status)
                                            return
                if Stalker42.verbose:
                        if status is False:
                                status = "all"
                        print("Stalker42: dictionary " + status + " ended")
                return (self.getInfo(ret))

        def connectIntra(self, user=False, pwd=False):
                data = {}
                if user and pwd:
                        data = {"login": user, "password": pwd}
                try:
                        intra = self.intraSession.post(self.urlIntra, data=data, verify=False)
                        intra.encoding = 'utf-8'
                        self.intra = intra.text
                        if Stalker42.verbose:
                                print("Stalker42: " + self.urlIntra + " connected")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect " + self.urlIntra)
                        return (False)
                if re.findall('Anonymous',self.intra):
                        return (False)
                return (True)

        def connectDashboard(self, user=False, pwd=False):
                data = {}
                headers = {"User-Agent" : "Mozilla/5.0 (X11; Linux x86_64; rv:12.0) Gecko/20100101 Firefox/21.0"}
                if user and pwd:
                        data = {"login": user, "password": pwd}
                try:
                        self.dashboard = self.dashboardSession.post(self.urlDashboard, data=data, headers=headers, verify=False)
                        if Stalker42.verbose:
                                print("Stalker42: " + self.urlDashboard + " connected")
                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect " + self.urlDashboard)
                        return (False)
                if re.findall('login',self.dashboard.text):
                        return (False)
                return(True)

        def findCorrector(self):
                ret = []
                if self.intra == None:
                        if Stalker42.verbose:
                                print("Stalker42: You must be connected to the intra")
                        return ()
                soup = BeautifulSoup(self.intra)
                peer = soup.find_all("div", {"class": "column peering"})
                for block in peer:
                        block = block.get_text()
                        try:
                                project = re.search("sur le projet (.+) avant", block).group(1)
                        except:
                                project = "Not found"
                        match = re.findall('(\(e\) par )(.+)( )', block)
                        if match:
                                for corrector in match:
                                             ret.append({'name': corrector[1],
                                                         'project': project,
                                                         'status': 'corrector'})
                return(self.getInfo(ret))

        def connectLdap(self, login, pwd): # connec to ldap and put tel mail uid in self.ldap
                try:
                        user = ('uid='+ login + ', ou=2013, ou=people, dc=42, dc=fr')
                        server = Server(self.urlLdap, port = 636, use_ssl = True)
                        connection = Connection(server, auto_bind = True, client_strategy = STRATEGY_SYNC, user=user, password=pwd, authentication=AUTH_SIMPLE)

                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect to ldap")
                        return (False)
                try:
                        connection.search('ou=people, dc=42, dc=fr','(objectClass=*)', SEARCH_SCOPE_WHOLE_SUBTREE, attributes = ['uid', 'alias', 'mobile-phone'])
                        self.ldap = connection.response
                        connection.unbind()
                except:
                        if Stalker42.verbose:
                                print("Stalker42: ldap search error")
                        connection.unbind()
                        return (False)
                if Stalker42.verbose:
                        print("Stalker42: " + self.urlLdap + " connected")
                return (True)

        def connectLdapSchool(self): # connec to ldap and put tel mail uid in self.ldap at school
                try:
                        user = ('ou=2013, ou=people, dc=42, dc=fr')
                        server = Server(self.urlLdap, port = 389)
                        connection = Connection(server, auto_bind = True, client_strategy = STRATEGY_SYNC, user=user)

                except:
                        if Stalker42.verbose:
                                print("Stalker42: can't connect to ldap")
                        return (False)
                try:
                        connection.search('ou=people, dc=42, dc=fr','(objectClass=*)', SEARCH_SCOPE_WHOLE_SUBTREE, attributes = ['uid', 'alias', 'mobile-phone'])
                        self.ldap = connection.response
                        connection.unbind()
                except:
                        if Stalker42.verbose:
                                print("Stalker42: ldap search error")
                        connection.unbind()
                        return (False)
                if Stalker42.verbose:
                        print("Stalker42: " + self.urlLdap + " connected")
                return (True)

        def getMail(self, name):
                if self.ldap:
                        for user in self.ldap:
                                attr = user['attributes']
                                try:
                                        if attr['uid'][0] == name:
                                               return (attr['alias'][0])
                                except:
                                        if Stalker42.verbose:
                                               print("Stalker42: can't find ldap element")
                return ('Not found')

        def getTel(self, name):
                if self.ldap:
                        for user in self.ldap:
                                attr = user['attributes']
                                try:
                                        if attr['uid'][0] == name:
                                               return (attr['mobile-phone'][0])
                                except:
                                        if Stalker42.verbose:
                                               print("Stalker42: can't find ldap element")
                return ('Not found')                      

        def __del__(self):
                if Stalker42.verbose:
                        print("Stalker42: object deleted")
